.. raw:: html

   <div align="center">
   <img src="docs/logo.png" width="450px">
   </img>
   <br/>
   </div>
   <br/><br/>

Spectroscopy for planetary atmospheres.

Docs 
----

.. raw:: html

	 <div class="row">
	  <div class="col-md-3">
	    <div class="thumbnail">
	      <a href="https://natashabatalha.github.io/picaso">
	        <img src="docs/file-alt-regular.svg" alt="installation" width="30px">
	      </a>
	    </div>
	</div>

Paper 
-----

.. raw:: html

	 <div class="row">
	  <div class="col-md-3">
	    <div class="thumbnail">
	      <a href="https://natashabatalha.github.io/picaso">
	        <img src="docs/scroll-solid.svg" alt="installation" width="30px">
	      </a>
	    </div>
	</div>

Math 
----

.. raw:: html

	 <div class="row>
	  <div class="col-md-3">
	    <div class="thumbnail">
	      <a href="https://natashabatalha.github.io/picaso_dev">
	        <img src="docs/chalkboard-solid.svg" alt="installation" width="30px">
	      </a>
	    </div>
	</div>

.. image:: https://travis-ci.com/natashabatalha/picaso.svg?token=rhFPvNo2sGUpKx2Zyx86&branch=master
    :target: https://travis-ci.com/natashabatalha/picaso

.. image:: https://zenodo.org/badge/113474583.svg
   :target: https://zenodo.org/badge/latestdoi/113474583
